function [X,y]=mixt_model(m,S,P,N,sed)

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% FUNCTION
%   [X,y]=mixt_model(m,S,P,N,sed)
% Generates a set of data vectors that stem from a mixture of normal 
% distributions (also used in Chapter 2).
%
% INPUT ARGUMENTS:
%   m:  lxc matrix whose i-th column contains the
%       (l-dimensional) mean of the i-th normal distribution.
%   S:  lxlxc matrix whose i-th lxl two-dimensional "slice" is the
%       covariance matrix corresponding to the i-th normal distribution.
%   P:  c-dimensional vector whose i-th coordinate contains
%       the a priori probability for the i-th normal  distribution.
%   N:  the total number of points to be generated by the mixture
%       distribution.
%   sed:  the seed used for the initialization of the built-in MATLAB
%         random generator function "rand".
%
% OUTPUT ARGUMENTS:
%   X:  lxN matrix whose columns are the produced vectors.
%   y:  N-dimensional vector whose i-th element indicates the
%       distribution generated the i-th vector.
%
% (c) 2010 S. Theodoridis, A. Pikrakis, K. Koutroumbas, D. Cavouras
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

rand('seed',sed);
[l,c]=size(m);

%Constructing the P_acc vector. This is necessary for picking randomly
%one of the c normal distributions in order to generate a point.
P_acc=P(1);
for i=2:c
    t=P_acc(i-1)+P(i);
    P_acc=[P_acc t];
end

% Generation of the data set
X=[];
y=[];
for i=1:N
    t=rand;
    ind=sum(t>P_acc)+1;  % Index of the normal distribution that will generate the i-th vector
    X=[X; mvnrnd(m(:,ind)',S(:,:,ind),1)];
    y=[y ind];
end
X=X';